summaryrefslogtreecommitdiffstats
path: root/sim/ppc/std-config.h
diff options
context:
space:
mode:
authorMichael Meissner <gnu@the-meissners.org>1995-11-12 14:20:39 +0000
committerMichael Meissner <gnu@the-meissners.org>1995-11-12 14:20:39 +0000
commit28816f45f574ca788dd4e05b8ee7a140e01f3d84 (patch)
treeae6525ea117a94aa6fa239a43eb8633513158742 /sim/ppc/std-config.h
parentc05c182dd679dd98f39e59fd567f767c679fa13f (diff)
downloadppe42-binutils-28816f45f574ca788dd4e05b8ee7a140e01f3d84.tar.gz
ppe42-binutils-28816f45f574ca788dd4e05b8ee7a140e01f3d84.zip
Add support for setting model name and other things
Diffstat (limited to 'sim/ppc/std-config.h')
-rw-r--r--sim/ppc/std-config.h27
1 files changed, 26 insertions, 1 deletions
diff --git a/sim/ppc/std-config.h b/sim/ppc/std-config.h
index ace2888302..8a77d3ae3d 100644
--- a/sim/ppc/std-config.h
+++ b/sim/ppc/std-config.h
@@ -236,6 +236,12 @@ extern int current_floating_point;
#define WITH_ASSERT 1
#endif
+/* Whether to check instructions for reserved bits being set */
+
+#ifndef WITH_RESERVED_BITS
+#define WITH_RESERVED_BITS 1
+#endif
+
/* include monitoring code */
#define MONITOR_INSTRUCTION_ISSUE 1
@@ -282,6 +288,19 @@ extern ppc_model current_ppc_model;
? WITH_PPC_MODEL \
: current_ppc_model)
+/* Current CPU model (models are in the generated models.h include file) */
+#ifndef WITH_MODEL
+#define WITH_MODEL 0
+#endif
+
+#define CURRENT_MODEL (WITH_MODEL \
+ ? WITH_MODEL \
+ : current_model)
+
+#ifndef WITH_DEFAULT_MODEL
+#define WITH_DEFAULT_MODEL DEFAULT_MODEL
+#endif
+
/* INLINE CODE SELECTION:
GCC -O3 attempts to inline any function or procedure in scope. The
@@ -454,7 +473,13 @@ extern ppc_model current_ppc_model;
#define IDECODE_INLINE DEFAULT_INLINE
#endif
-/* Code to simule functional units of real machines */
+/* Model specific code used in simulating functional units */
+
+#ifndef MODEL_INLINE
+#define MODEL_INLINE DEFAULT_INLINE
+#endif
+
+/* Code to simulate functional units of real machines */
#ifndef FUNCTION_UNIT_INLINE
#define FUNCTION_UNIT_INLINE DEFAULT_INLINE
OpenPOWER on IntegriCloud